from taurus_datajob_api.paths.data_jobs_for_team_team_name_jobs_job_name_deployments_deployment_id.get import ApiForget
from taurus_datajob_api.paths.data_jobs_for_team_team_name_jobs_job_name_deployments_deployment_id.delete import ApiFordelete
from taurus_datajob_api.paths.data_jobs_for_team_team_name_jobs_job_name_deployments_deployment_id.patch import ApiForpatch


class DataJobsForTeamTeamNameJobsJobNameDeploymentsDeploymentId(
    ApiForget,
    ApiFordelete,
    ApiForpatch,
):
    pass
