from taurus_datajob_api.paths.data_jobs_for_team_team_name_jobs_job_name_executions_execution_id.get import ApiForget
from taurus_datajob_api.paths.data_jobs_for_team_team_name_jobs_job_name_executions_execution_id.delete import ApiFordelete


class DataJobsForTeamTeamNameJobsJobNameExecutionsExecutionId(
    ApiForget,
    ApiFordelete,
):
    pass
