from taurus_datajob_api.paths.data_jobs_for_team_team_name_jobs_job_name.get import ApiForget
from taurus_datajob_api.paths.data_jobs_for_team_team_name_jobs_job_name.put import ApiForput
from taurus_datajob_api.paths.data_jobs_for_team_team_name_jobs_job_name.delete import ApiFordelete


class DataJobsForTeamTeamNameJobsJobName(
    ApiForget,
    ApiForput,
    ApiFordelete,
):
    pass
