from taurus_datajob_api.paths.data_jobs_for_team_team_name_jobs_job_name_sources.get import ApiForget
from taurus_datajob_api.paths.data_jobs_for_team_team_name_jobs_job_name_sources.post import ApiForpost
from taurus_datajob_api.paths.data_jobs_for_team_team_name_jobs_job_name_sources.delete import ApiFordelete


class DataJobsForTeamTeamNameJobsJobNameSources(
    ApiForget,
    ApiForpost,
    ApiFordelete,
):
    pass
