from taurus_datajob_api.paths.data_jobs_for_team_team_name_jobs_job_name_deployments_deployment_id_executions.get import ApiForget
from taurus_datajob_api.paths.data_jobs_for_team_team_name_jobs_job_name_deployments_deployment_id_executions.post import ApiForpost


class DataJobsForTeamTeamNameJobsJobNameDeploymentsDeploymentIdExecutions(
    ApiForget,
    ApiForpost,
):
    pass
