from taurus_datajob_api.paths.data_jobs_for_team_team_name_jobs_job_name_deployments_deployment_id_properties.get import ApiForget
from taurus_datajob_api.paths.data_jobs_for_team_team_name_jobs_job_name_deployments_deployment_id_properties.put import ApiForput


class DataJobsForTeamTeamNameJobsJobNameDeploymentsDeploymentIdProperties(
    ApiForget,
    ApiForput,
):
    pass
