from taurus_datajob_api.paths.data_jobs_for_team_team_name_jobs.get import ApiForget
from taurus_datajob_api.paths.data_jobs_for_team_team_name_jobs.post import ApiForpost


class DataJobsForTeamTeamNameJobs(
    ApiForget,
    ApiForpost,
):
    pass
