# coding: utf-8

"""


    Generated by: https://openapi-generator.tech
"""

import unittest
from unittest.mock import patch

import urllib3

import taurus_datajob_api
from taurus_datajob_api.paths.data_jobs_for_team_team_name_jobs_job_name_deployments_deployment_id import patch  # noqa: E501
from taurus_datajob_api import configuration, schemas, api_client

from .. import ApiTestMixin


class TestDataJobsForTeamTeamNameJobsJobNameDeploymentsDeploymentId(ApiTestMixin, unittest.TestCase):
    """
    DataJobsForTeamTeamNameJobsJobNameDeploymentsDeploymentId unit test stubs
        Patch a deployment of a Data Job. Use it to change the configuration of a data job. For example: to enable or disable deployment, to change the vdk version. The operation is guranteed to be synchrounous so it cannot be used to deploy new version of a data job - job_version cannot be changed using PATCH. Use POST .../deployments for this. | (Stable)   # noqa: E501
    """
    _configuration = configuration.Configuration()

    def setUp(self):
        used_api_client = api_client.ApiClient(configuration=self._configuration)
        self.api = patch.ApiForpatch(api_client=used_api_client)  # noqa: E501

    def tearDown(self):
        pass

    response_status = 202
    response_body = ''




if __name__ == '__main__':
    unittest.main()
