from taurus_datajob_api.paths.data_jobs_for_team_team_name_jobs_job_name_executions_execution_id_logs.get import ApiForget


class DataJobsForTeamTeamNameJobsJobNameExecutionsExecutionIdLogs(
    ApiForget,
):
    pass
